# API Reference

## Benchmark

```{eval-rst}
.. autoclass:: zerobench.Benchmark
   :members:
   :undoc-members:
   :show-inheritance:
```

## BenchmarkPlotter

```{eval-rst}
.. autoclass:: zerobench.BenchmarkPlotter
   :members:
   :undoc-members:
   :show-inheritance:
```
